@@ -1,4 +1,4 @@
-from typing import Optional
+from typing import Optional, Collection
 
 import redis
 
@@ -17,10 +17,17 @@ class RedisBackend(BaseBackend):
         self.client = redis.StrictRedis(
             host=app_settings.REDIS_HOST,
             port=app_settings.REDIS_PORT,
+            password=app_settings.REDIS_PASSWORD,
         )
 
     def enqueue(self, job: Job, queue: QueueName) -> None:
-        self.client.lpush(self._key(queue), job.to_json().encode('utf-8'))
+        return self.bulk_enqueue([job], queue)
+
+    def bulk_enqueue(self, jobs: Collection[Job], queue: QueueName) -> None:
+        self.client.lpush(
+            self._key(queue),
+            *(job.to_json().encode('utf-8') for job in jobs),
+        )
 
     def dequeue(self, queue: QueueName, worker_num: WorkerNumber, timeout: int) -> Optional[Job]:
         raw = self.client.brpop(self._key(queue), timeout)
